using BinaryProvider
using CxxWrap # this is needed for opening the dependency lib. Otherwise Libdl.dlopen fails

##################### LCIO ###########################
# We are trying to find the right version of LCIO. By default, don't set anything and the right version will just be downloaded. However, for debugging purposes, we'd might want to use the pre-installed lib
const lcioversion = "02-12-01"
const LCIO_DIR = get(ENV, "LCIO_DIR", "")
const verbose = "--verbose" in ARGS
const lcioprefix = Prefix(LCIO_DIR == "" ? get([a for a in ARGS if a != "--verbose"], 1, joinpath(@__DIR__, "usr")) : LCIO_DIR)

# The products that we will ensure are always built
lcioproducts = [
    LibraryProduct(lcioprefix, "liblcio", :liblcio),
    LibraryProduct(lcioprefix, "libsio", :libsio)
]
# Download binaries from hosted location
bin_prefix = "https://github.com/jstrube/LCIOBuilder/releases/download/v2.12.1"

# Listing of files generated by BinaryBuilder:
download_info = Dict(
    MacOS(:x86_64) => ("$bin_prefix/LCIOBuilder.v2.12.1.x86_64-apple-darwin14.tar.gz", "0f869074705058746eaae5198e0edf494ad0d66e4e212f16864a529703e4740e"),
    Linux(:x86_64) => ("$bin_prefix/LCIOBuilder.v2.12.1.x86_64-linux-gnu.tar.gz", "6377e5cd3a45f5a15dd54462cb113fd73ff26608d77c8780a9962c2babdb703c"),
)

# Install unsatisfied or updated dependencies:
unsatisfied = any(!satisfied(p; verbose=verbose) for p in lcioproducts)
if haskey(download_info, platform_key())
    url, tarball_hash = download_info[platform_key()]
    if unsatisfied || !isinstalled(url, tarball_hash; prefix=lcioprefix)
        # Download and install binaries
        install(url, tarball_hash; prefix=lcioprefix, force=true, verbose=verbose)
    end
elseif unsatisfied
    # If we don't have a BinaryProvider-compatible .tar.gz to download, complain.
    # Alternatively, you could attempt to install from a separate provider,
    # build from source or something even more ambitious here.
    error("Your platform $(triplet(platform_key())) is not supported by this package!")
end

######################################################

################### LCIO Wrapper #####################
const wrapprefix = Prefix(joinpath(@__DIR__, "usr"))

# Download binaries from hosted location
bin_prefix = "https://github.com/jstrube/LCIOWrapBuilder/releases/download/v0.4.3"

# Listing of files generated by BinaryBuilder:
download_info = Dict(
    MacOS(:x86_64) => ("$bin_prefix/LCIOWrapBuilder.v0.4.3.x86_64-apple-darwin14.tar.gz", "df9180831e47a69953083f335d8f8c88983a6e4224c2ab730e55ecff7ae56646"),
    Linux(:x86_64) => ("$bin_prefix/LCIOWrapBuilder.v0.4.3.x86_64-linux-gnu.tar.gz", "ce2a6991026e8aa624b6410354c3494f3d8000b722928c84c33ada945571a03b"),
)

# The products that we will ensure are always built
wrapproducts = [
    LibraryProduct(wrapprefix, "liblciowrap", :liblciowrap)
]

# Install unsatisfied or updated dependencies:
unsatisfied = any(!satisfied(p; verbose=verbose) for p in wrapproducts)
if haskey(download_info, platform_key())
    url, tarball_hash = download_info[platform_key()]
    if unsatisfied || !isinstalled(url, tarball_hash; prefix=wrapprefix)
        # Download and install binaries
        install(url, tarball_hash; prefix=wrapprefix, force=true, verbose=verbose)
    end
elseif unsatisfied
    # If we don't have a BinaryProvider-compatible .tar.gz to download, complain.
    # Alternatively, you could attempt to install from a separate provider,
    # build from source or something even more ambitious here.
    error("Your platform $(triplet(platform_key())) is not supported by this package!")
end
######################################################
write_deps_file(joinpath(@__DIR__, "deps.jl"), [lcioproducts; wrapproducts])
